@@ -7,7 +7,14 @@ from prompt_toolkit.document import Document
 from prompt_toolkit.shortcuts import checkboxlist_dialog, radiolist_dialog
 from prompt_toolkit.validation import ValidationError, Validator
 
-from fastapi_template.input_model import BuilderContext, Database, DatabaseType, CIType
+from fastapi_template.input_model import (
+    ORM,
+    BuilderContext,
+    DB_INFO,
+    DatabaseType,
+    CIType,
+)
+from importlib.metadata import version
 
 
 class SnakeCaseValidator(Validator):
@@ -17,34 +24,13 @@ class SnakeCaseValidator(Validator):
             raise ValidationError(message="Must be a valid snake_case name.")
 
 
-DB_INFO = {
-    DatabaseType.none: Database(
-        name="none",
-        image="none",
-        driver=None,
-        port=None,
-    ),
-    DatabaseType.postgresql: Database(
-        name=DatabaseType.postgresql.value,
-        image="postgres:13.4-buster",
-        driver="postgresql+asyncpg",
-        port=5432,
-    ),
-    DatabaseType.mysql: Database(
-        name=DatabaseType.mysql.value,
-        image="bitnami/mysql:8.0.26",
-        driver="mysql+aiomysql",
-        port=3306,
-    ),
-    DatabaseType.sqlite: Database(
-        name=DatabaseType.sqlite.value, image=None, driver="sqlite+aiosqlite", port=None
-    ),
-}
-
 def parse_args():
     parser = ArgumentParser(
         prog="FastAPI template",
     )
+    parser.add_argument(
+        "--version", "-V", action="store_true", help="Prints current version"
+    )
     parser.add_argument(
         "--name",
         type=str,
@@ -66,6 +52,14 @@ def parse_args():
         default=None,
         dest="db",
     )
+    parser.add_argument(
+        "--orm",
+        help="ORM",
+        type=str,
+        choices=list(map(attrgetter("value"), ORM)),
+        default=None,
+        dest="orm",
+    )
     parser.add_argument(
         "--ci",
         help="Choose CI support",
@@ -82,11 +76,11 @@ def parse_args():
         dest="enable_redis",
     )
     parser.add_argument(
-        "--alembic",
-        help="Add alembic support",
+        "--migrations",
+        help="Add migrations support",
         action="store_true",
         default=None,
-        dest="enable_alembic",
+        dest="enable_migrations",
     )
     parser.add_argument(
         "--kube",
@@ -146,18 +140,16 @@ def ask_features(current_context: BuilderContext) -> BuilderContext:
             "name": "self_hosted_swagger",
             "value": current_context.self_hosted_swagger,
         },
-
     }
     if current_context.db != DatabaseType.none:
-        features["Alembic migrations"] = {
-            "name": "enable_alembic",
-            "value": current_context.enable_alembic,
+        features["Migrations support"] = {
+            "name": "enable_migrations",
+            "value": current_context.enable_migrations,
         }
         features["Add dummy model"] = {
             "name": "add_dummy",
-            "value": current_context.add_dummy
+            "value": current_context.add_dummy,
         }
-
     checkbox_values = []
     for feature_name, feature in features.items():
         if feature["value"] is None:
@@ -181,7 +173,7 @@ def read_user_input(current_context: BuilderContext) -> BuilderContext:
         current_context.project_name = prompt(
             "Project name: ", validator=SnakeCaseValidator()
         )
-    current_context.kube_name = current_context.project_name.replace('_', '-')
+    current_context.kube_name = current_context.project_name.replace("_", "-")
     if current_context.project_description is None:
         current_context.project_description = prompt("Project description: ")
     if current_context.db is None:
@@ -192,8 +184,17 @@ def read_user_input(current_context: BuilderContext) -> BuilderContext:
         ).run()
         if current_context.db is None:
             raise KeyboardInterrupt()
-        if current_context.db == DatabaseType.none:
-            current_context.enable_alembic = False
+    if current_context.db == DatabaseType.none:
+        current_context.enable_migrations = False
+        current_context.add_dummy = False
+    elif current_context.orm is None:
+        current_context.orm = radiolist_dialog(
+            "ORM",
+            text="Which ORM do you want?",
+            values=[(orm, orm.value) for orm in list(ORM)],
+        ).run()
+        if current_context.orm is None:
+            raise KeyboardInterrupt()
     if current_context.ci_type is None:
         current_context.ci_type = radiolist_dialog(
             "CI",
@@ -208,6 +209,9 @@ def read_user_input(current_context: BuilderContext) -> BuilderContext:
 
 def get_context() -> BuilderContext:
     args = parse_args()
+    if args.version:
+        print(version("fastapi_template"))
+        exit(0)
     context = BuilderContext.from_orm(args)
     context = read_user_input(context)
     context.db_info = DB_INFO[context.db]
