@@ -6,16 +6,16 @@ import subprocess
 
 from pygit2 import init_repository
 from termcolor import cprint, colored
+from pathlib import Path
 
 MANIFEST = "conditional_files.json"
+REPLACE_MANIFEST = "replaceable_files.json"
 
 
 def delete_resource(resource):
     if os.path.isfile(resource):
-        print("removing file: {}".format(resource))
         os.remove(resource)
     elif os.path.isdir(resource):
-        print("removing directory: {}".format(resource))
         shutil.rmtree(resource)
 
 
@@ -23,18 +23,39 @@ def delete_resources_for_disabled_features():
     with open(MANIFEST) as manifest_file:
         manifest = json.load(manifest_file)
         for feature_name, feature in manifest.items():
-            if feature['enabled'].lower() != "true":
+            if feature["enabled"].lower() != "true":
                 text = "{} resources for disabled feature {}...".format(
                     colored("Removing", color="red"),
-                    colored(feature_name, color="magenta", attrs=['underline'])
+                    colored(feature_name, color="magenta", attrs=["underline"]),
                 )
                 print(text)
-                for resource in feature['resources']:
+                for resource in feature["resources"]:
                     delete_resource(resource)
     delete_resource(MANIFEST)
     cprint("cleanup complete!", color="green")
 
 
+def replace_resources():
+    print(
+        "⭐ Placing {} nicely in your {} ⭐".format(
+            colored("resources", color="green"), colored("new project", color="blue")
+        )
+    )
+    with open(REPLACE_MANIFEST) as replace_manifest:
+        manifest = json.load(replace_manifest)
+        for target, replaces in manifest.items():
+            target_path = Path(target)
+            delete_resource(target_path)
+            for src_file in map(Path, replaces):
+                if src_file.exists():
+                    shutil.move(src_file, target_path)
+    print(
+        "Resources are happy to be where {}.".format(
+            colored("they are needed the most", color="green", attrs=["underline"])
+        )
+    )
+
+
 def init_repo():
     repo_path = os.getcwd()
     repo = init_repository(repo_path)
@@ -52,4 +73,5 @@ def init_repo():
 
 if __name__ == "__main__":
     delete_resources_for_disabled_features()
+    replace_resources()
     init_repo()
